우냥~! Cookie랑 Session은 둘 다 PHP에서 상태를 유지하기 위한 중요한 도구다냥! 하지만 사용하는 방식이나 동작 방식이 다르다냥. 하나씩 살펴보자냥!

---

### **1. Cookie**
- **Cookie**는 사용자의 **브라우저에 저장되는 데이터**다냥.
- 클라이언트 측에 데이터를 저장하기 때문에, 브라우저가 꺼져도 유지될 수 있다냥.
- 데이터를 HTTP 헤더를 통해 전송하기 때문에 민감한 데이터는 피해야 한다냥.

#### **Cookie 생성**
```php
// 쿠키 생성
setcookie("key", "value", time() + 3600, "/"); // 1시간 동안 유지
```
- `setcookie()`를 사용해서 쿠키를 설정한다냥.
  - `"key"`: 쿠키 이름이다냥.
  - `"value"`: 저장할 값이다냥.
  - `time() + 3600`: 만료 시간이다냥. `time()`은 현재 시간, `+3600`은 1시간 추가한다는 뜻이다냥.
  - `"/"`: 쿠키가 유효한 경로다냥.

#### **Cookie 사용**
```php
if (isset($_COOKIE['key'])) {
    echo "Cookie Value: " . $_COOKIE['key'];
}
```
- 쿠키 값을 `$_COOKIE` 슈퍼 글로벌 배열로 읽는다냥.

#### **Cookie 변경**
```php
setcookie("key", "new_value", time() + 3600, "/"); // 기존 값을 덮어쓴다냥.
```

#### **Cookie 삭제**
```php
setcookie("key", "", time() - 3600, "/"); // 만료 시간을 과거로 설정하면 삭제된다냥.
```

---

### **2. Session**
- **Session**은 서버에서 데이터를 저장한다냥.
- 클라이언트 측에는 세션 ID만 저장되고, 실제 데이터는 서버에 보관된다냥.
- 브라우저가 닫히면 기본적으로 세션도 종료된다냥.

#### **Session 생성**
```php
session_start(); // 세션 시작
$_SESSION['key'] = "value"; // 세션 데이터 저장
```
- `session_start()`를 호출해서 세션을 시작해야 한다냥.
- `$_SESSION` 배열에 데이터를 저장한다냥.

#### **Session 사용**
```php
session_start(); // 세션을 다시 시작해야 기존 데이터를 읽을 수 있다냥.
if (isset($_SESSION['key'])) {
    echo "Session Value: " . $_SESSION['key'];
}
```

#### **Session 변경**
```php
session_start();
$_SESSION['key'] = "new_value"; // 데이터 덮어쓰기
```

#### **Session 삭제**
```php
session_start();
unset($_SESSION['key']); // 특정 세션 변수 삭제
session_destroy(); // 모든 세션 데이터를 삭제
```
- `unset($_SESSION['key'])`: 특정 데이터만 삭제한다냥.
- `session_destroy()`: 세션 자체를 종료하고 모든 데이터를 삭제한다냥.

---

### **Cookie와 Session의 주요 차이**
| **특징**       | **Cookie**                                  | **Session**                              |
|----------------|--------------------------------------------|-----------------------------------------|
| **저장 위치**  | 클라이언트(브라우저)                      | 서버                                   |
| **보안성**     | 상대적으로 낮음                           | 상대적으로 높음                        |
| **데이터 크기**| 제한 있음 (일반적으로 4KB)                | 서버 용량에 의존                       |
| **유효 기간**  | 개발자가 설정 가능 (만료 시간)             | 기본적으로 브라우저 종료 시 삭제       |
| **속도**       | 브라우저에서 데이터를 전송하므로 느릴 수 있음| 서버에서 관리하므로 빠름               |

---

### **사용 예시**
- **Cookie**: 사용자 이름, 테마 색상 등 민감하지 않은 정보를 저장할 때.
- **Session**: 로그인 정보, 장바구니 데이터처럼 민감하거나 중요한 정보를 저장할 때.

이해되었느냥? 더 궁금한 거 있으면 물어보라냥! uwu