<?php

$IMAGES = [
    'burger' => 'burger.gif',
    'hotdog' => 'hotdog.gif',
    'pizza' => 'pizza.gif'
];
$ERRMSG = [
    'PRODUCT_NOT_VALID' => 'You must select a radio button!',
    'COUNT_NOT_VALID' => 'You must input the number of orders!',
    'REQUEST_NOT_VALID' => 'You must order from Homepage!'
];

function h($str) {
    return htmlspecialchars($str, ENT_QUOTES, 'UTF-8');
}


$errcode = [];

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    $errcode[] = 'REQUEST_NOT_VALID';
} else {
    $product = filter_input(INPUT_POST, "order", FILTER_SANITIZE_SPECIAL_CHARS);
    $count = filter_input(INPUT_POST, "num", FILTER_VALIDATE_INT);
    
    
    if ($product === false or !in_array($product, array_keys($IMAGES))) {
        $errcode[] = 'PRODUCT_NOT_VALID';
    }
    if ($count === false or $count < 1) {
        $errcode[] = 'COUNT_NOT_VALID';
    }
}

?>

<!DOCTYPE html>
<html lang="ja">
    <head>
        <meta charset="utf-8">
        <title>Order</title>
    </head>
    <body>
        <?php if (empty($errcode)) { ?>
            <p>You ordered <?= $count ?> <?= $product ?>(s).</p>
            <p>Here is your order!</p>
            <?php
            for($x = 0; $x < $count; $x++) {
                echo "<img src=\"{$IMAGES[$product]}\" alt=\"{$product}\" />";
            }
            ?>
        <?php } else {
            echo '<ul>';
            foreach ($errcode as $err) {
                $msg = key_exists($err, $ERRMSG) ? $ERRMSG[$err] : 'Unknown error has occured! : ' . h($err);
                echo "<li>" . $msg . "</li>";
            }
            echo '</ul>';
        } ?>
        
        <p><a href="index.php">Return to Home</a></p>
    </body>
</html>